# vim: set ts=4 sw=4 sts=0 :
#
# Copyright (C) 2004, Shu KONNO <owa@bg.wakwak.com> All Rights Reserved.
#
from __init__ import opening_stage_figure
from CSpace import CSpace
import PIL.Image, string
from PIL.PngImagePlugin import PngInfo

import C14gBoard, C31cBoard
space_board = {0:C14gBoard.CxBoard, 1:C31cBoard.CxBoard}

class ViewSpace(CSpace):
	def __init__(self, diagram=None, size=0):
		CSpace.__init__(self)
		self.ban = space_board.get(int(size), C14gBoard.CxBoard)()
		self.size = int(size)
		if diagram:
			diagram = opening_stage_figure.get(diagram, diagram)
			CSpace.putDiagram(self, diagram)

	def pickupTarget(self, pos, id=0):
		return self.ban.pickupTarget(self, pos, id)

	def getposFromCoord(self, pos):
		return self.ban.getColRow(pos)

	def getPuzzleImage(self, pick=None):
		b = self.ban.getBoardImage(self, pick)
		c = self.ban.getBlacketImg(self, 1)
		x = b.size[0] + c.size[0]
		y = b.size[1]
		img = PIL.Image.new('RGBA',(x, y),(0,0,0,0))
		img.paste(b, (0, 0))
		img.paste(c, (b.size[0], b.size[1] - c.size[1]))
		return self._img2file(img)

	def getWholeImage(self, pick=None):
		a = self.ban.getBlacketImg(self, 2)
		b = self.ban.getBoardImage(self, pick)
		c = self.ban.getBlacketImg(self, 1)
		x = a.size[0] + b.size[0] + c.size[0]
		y = b.size[1]
		img = PIL.Image.new('RGBA',(x, y),(0,0,0,0))
		img.paste(a, (0, 0))
		img.paste(b, (a.size[0], 0))
		img.paste(c, (a.size[0] + b.size[0], b.size[1] - c.size[1]))
		return self._img2file(img)

	def getBoardImage(self, pick=None):
		img = self.ban.getBoardImage(self, pick)
		return self._img2file(img)

	def getBlackBlacket(self, pick=None, size=0):
		img = self.ban.getBlacketImg(self, 1, pick)
		return self._img2file(img)

	def getWhiteBlacket(self, pick=None, size=0):
		img = self.ban.getBlacketImg(self, 2, pick)
		return self._img2file(img)

	def _img2file(self, img):
		import cStringIO
		ram = cStringIO.StringIO()
		info = PngInfo()
		info.add('bKGD', '\000\377\000\377\000\377')
		img.save(ram, format='PNG', dpi=(72,72), pnginfo=info)
		ram.seek(0)
		return ram.getvalue()

